@@ -2,7 +2,7 @@ import atexit
 import logging
 import StringIO
 import sys
-from gitgoggles.utils import console, force_unicode
+from gitgoggles.utils import console, force_unicode, force_str
 
 class ProgressStreamHandler(logging.StreamHandler):
     def __init__(self, *args, **kwargs):
@@ -29,7 +29,7 @@ class ProgressStreamHandler(logging.StreamHandler):
             msg = ' %s   %s' % (self.spinner[0], self.msg)
             self.max_length = max(len(msg), self.max_length)
             self.spinner = self.spinner[1:] + self.spinner[:1]
-            sys.__stdout__.write(msg.ljust(self.max_length))
+            sys.__stdout__.write(force_str(msg.ljust(self.max_length)))
             sys.__stdout__.write('\r')
 
 def enable_progress():
